Struct cons_rs::List

source ·
pub struct List<T> { /* private fields */ }
A singly linked list. See the crate-level documentation for more.

Implementations

source

impl<T> List<T>

source

pub const fn new() -> Self

Creates an empty List.

Examples
use cons_rs::List;

let list: List<i32> = List::new();
source

pub fn push(&mut self, element: T)

Prepends an element to the beginning of the List.

Examples
use cons_rs::List;
 
let mut list = List::new();

list.push(1);
assert_eq!(list.peek(), Some(&1));

list.push(2);
assert_eq!(list.peek(), Some(&2));
source

pub fn pop(&mut self) -> Option<T>

Removes the element at the front of the List, and returns it.

Examples
use cons_rs::List;
 
let mut list = List::new();
assert_eq!(list.pop(), None);

list.push(1);

assert_eq!(list.pop(), Some(1));
assert_eq!(list.pop(), None);
source

pub fn is_empty(&self) -> bool

Checks if the List is empty.

Examples
use cons_rs::List;
 
let mut list = List::new();
assert!(list.is_empty());

list.push(1);
assert!(!list.is_empty());
source

pub fn len(&self) -> usize

Returns the length of the List.

Examples
use cons_rs::List;

let mut list = List::new();
assert_eq!(list.len(), 0);

list.push(1);
assert_eq!(list.len(), 1);
source

pub fn peek(&self) -> Option<&T>

Returns an immutable reference to the value at the head of the List, if it exists.

Examples
use cons_rs::List;
 
let mut list = List::new();
assert_eq!(list.peek(), None);

list.push(1);
assert_eq!(list.peek(), Some(&1));
source

pub fn peek_mut(&mut self) -> Option<&mut T>

Returns a mutable reference to the value at the head of the List, if it exists.

Examples
use cons_rs::List;
 
let mut list = List::new();
assert_eq!(list.peek_mut(), None);

list.push(1);
assert_eq!(list.peek_mut(), Some(&mut 1));

*list.peek_mut().unwrap() = 50;
assert_eq!(list.peek_mut(), Some(&mut 50));
source

pub fn iter(&self) -> Iter<'_, T>

Creates an iterator that yields shared references to all the elements in the List.

To get mutable references, see iter_mut.

Examples
use cons_rs::List;
 
let mut list = List::new();

list.push(1);
list.push(2);

let mut iter = list.iter();
assert_eq!(iter.next(), Some(&2));
assert_eq!(iter.next(), Some(&1));
assert_eq!(iter.next(), None);
source

pub fn iter_mut(&mut self) -> IterMut<'_, T>

Creates an iterator that yields mutable references to all the elements in the List.

To get shared references, see iter.

Examples
use cons_rs::List;
 
let mut list = List::new();
 
list.push(1);
list.push(2);

for elem in list.iter_mut() {
    *elem += 10;
}

assert_eq!(list.pop(), Some(12));
assert_eq!(list.pop(), Some(11));
assert_eq!(list.pop(), None);