Enum cons_rs::List

source ·
pub enum List<T> {
    Cons(T, Box<List<T>>),
    Nil,
}
An enum that represents a Cons list. See the module level documentation for more.

Variants



Cons(T, Box<List<T>>)

A value of type T, and a Box containing another list.



Nil

Nothing.

Implementations

source

impl<T> List<T>

source

pub const fn is_cons(&self) -> bool

Returns true if the List is a Cons value.

Examples
use cons_rs::{List, Cons, Nil};

let x: List<i32> = Cons(5, Box::new(Nil));
assert_eq!(x.is_cons(), true);

let x: List<i32> = Nil;
assert_eq!(x.is_cons(), false);
source

pub const fn is_nil(&self) -> bool

Returns true if the List is a Nil value.

Examples:
use cons_rs::{List, Cons, Nil};

let x: List<i32> = Cons(5, Box::new(Nil));
assert_eq!(x.is_nil(), false);

let x: List<i32> = Nil;
assert_eq!(x.is_nil(), true);
source

pub fn unwrap(self) -> (T, List<T>)

Gets the value and next List, by consuming self.

Panics

Panics if self is Nil.