pub struct List<T> { /* private fields */ }Expand description
A singly linked list. See the [crate-level documentation] (crate) for more.
Implementations
sourceimpl<T> List<T>
impl<T> List<T>
sourcepub fn pop(&mut self) -> Option<T>
pub fn pop(&mut self) -> Option<T>
Removes the element at the front of the List,
and returns it.
sourcepub fn peek(&self) -> Option<&T>
pub fn peek(&self) -> Option<&T>
Returns an immutable reference to the value
at the head of the List, if it exists.
sourcepub fn peek_mut(&mut self) -> Option<&mut T>
pub fn peek_mut(&mut self) -> Option<&mut T>
Returns a mutable reference to the value
at the head of the List, if it exists.